diff --git a/dumux/porousmediumflow/richardsextended/model.hh b/dumux/porousmediumflow/richardsextended/model.hh
index 0c04bd0a8c057190965e09f6827bf01b6753f01f..49922b3f1a6c4df0ec12feeb97c96f3f01019929 100644
--- a/dumux/porousmediumflow/richardsextended/model.hh
+++ b/dumux/porousmediumflow/richardsextended/model.hh
@@ -37,63 +37,14 @@
  * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
  * * \f$ p_w \f$ is the pressure of the wetting phase,
  * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ \bf D_{n,pm}^{w} \f$ is the diffusivity of water in the non-wetting phase,
+ * * \f$ \bf D_{n,pm}^{w} \f$ is the effective diffusivity of water in the non-wetting phase,
  * * \f$ X_n^w \f$ is the mass fraction of water in the non-wetting phase,
  * * \f$ q_w \f$ is a source or sink term in the wetting phase,
  *
- * is frequently used to
- * approximate the water distribution above the groundwater level.
- *
- * It can be derived from the two-phase equations, i.e.
- \f[
- \phi\frac{\partial S_\alpha \varrho_\alpha}{\partial t}
- -
- \nabla \cdot \left\lbrace
- \varrho_\alpha \frac{k_{r\alpha}}{\mu_\alpha}\; \mathbf{K} \;
- \left( \text{\nabla}
- p_\alpha - \varrho_\alpha \textbf{g}
- \right)
- \right\rbrace
- =
- q_\alpha,
- \f]
- *
- * where:
- * * \f$ \phi \f$ is the porosity of the porous medium,
- * * \f$ S_\alpha \f$ represents the saturation of phase \f$ \alpha \f$,
- * * \f$ \varrho_\alpha \f$ is the mass density of phase \f$ \alpha \f$,
- * * \f$ k_{r\alpha} \f$ is the relative permeability of phase \f$ \alpha \f$,
- * * \f$ \mu_\alpha \f$ is the dynamic viscosity of phase \f$ \alpha \f$,
- * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
- * * \f$ p_\alpha \f$ is the pressure of phase \f$ \alpha \f$,
- * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ q_\alpha \f$ is a source or sink term.
- *
- * In contrast to the full two-phase model, the Richards model assumes
- * gas as the nonwetting fluid and that it exhibits a much lower
- * viscosity than the (liquid) wetting phase. (For example at
- * atmospheric pressure and at room temperature, the viscosity of air
- * is only about \f$1\%\f$ of the viscosity of liquid water.) As a
- * consequence, the \f$\frac{k_{r\alpha}}{\mu_\alpha}\f$ term
- * typically is much larger for the gas phase than for the wetting
- * phase. For this reason, the Richards model assumes that
- * \f$\frac{k_{rn}}{\mu_n}\f$ is infinitely large. This implies that
- * the pressure of the gas phase is equivalent to the static pressure
- * distribution and that therefore, mass conservation only needs to be
- * considered for the wetting phase.
- *
- * The model thus chooses the absolute pressure of the wetting phase
- * \f$p_w\f$ as its only primary variable. The wetting phase
- * saturation is calculated using the inverse of the capillary
- * pressure, i.e.
- \f[
- S_w = p_c^{-1}(p_n - p_w)
- \f]
- * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
- * that the last step is assumes that the capillary
- * pressure-saturation curve can be uniquely inverted, so it is not
- * possible to set the capillary pressure to zero when using the
- * Richards model!
+ * additionally models water vapor diffusion in the gas phase.
+ * The model is derived based on the two-phase flow equations
+ * based on the assumption that the gas phase does not move but
+ * and remains at constant pressure.
  */
 
 #ifndef DUMUX_RICHARDSEXTENDED_MODEL_HH
diff --git a/dumux/porousmediumflow/richardsnc/model.hh b/dumux/porousmediumflow/richardsnc/model.hh
index 737f318cd671b74bdb660bf744cc032769334485..813666b637968139d80e210a8b5ee39f2dd35810 100644
--- a/dumux/porousmediumflow/richardsnc/model.hh
+++ b/dumux/porousmediumflow/richardsnc/model.hh
@@ -10,7 +10,8 @@
  * \brief Base class for all models which use the Richards,
  *        n-component fully implicit model.
  *
- * In the unsaturated zone, Richards' equation
+ * This extension of Richards' equation, allows for
+ * the wetting phase to consist of multiple components:
  *\f{eqnarray*}
  && \frac{\partial (\sum_w \varrho_w X_w^\kappa \phi S_w )}
  {\partial t}
@@ -31,38 +32,9 @@
  * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
  * * \f$ p_w \f$ is the pressure of the wetting phase,
  * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ \bf D_{w,pm}^{k} \f$ is the diffusivity of component \f$ \kappa \f$ in the wetting phase,
+ * * \f$ \bf D_{w,pm}^{k} \f$ is the effective diffusivity of component \f$ \kappa \f$ in the wetting phase,
  * * \f$ X_w^k \f$ is the mass fraction of component \f$ \kappa \f$ in the wetting phase,
- * * \f$ q_w \f$ is a source or sink term in the wetting phase,
- *
- * is frequently used to
- * approximate the water distribution above the groundwater level.
- *
- * In contrast to the full two-phase model, the Richards model assumes
- * gas as the nonwetting fluid and that it exhibits a much lower
- * viscosity than the (liquid) wetting phase. (For example at
- * atmospheric pressure and at room temperature, the viscosity of air
- * is only about \f$1\%\f$ of the viscosity of liquid water.) As a
- * consequence, the \f$\frac{k_{r\alpha}}{\mu_\alpha}\f$ term
- * typically is much larger for the gas phase than for the wetting
- * phase. For this reason, the Richards model assumes that
- * \f$\frac{k_{rn}}{\mu_n}\f$ is infinitely large. This implies that
- * the pressure of the gas phase is equivalent to the static pressure
- * distribution and that therefore, mass conservation only needs to be
- * considered for the wetting phase.
- *
- * The model thus chooses the absolute pressure of the wetting phase
- * \f$p_w\f$ as its only primary variable. The wetting phase
- * saturation is calculated using the inverse of the capillary
- * pressure, i.e.
- \f[
- S_w = p_c^{-1}(p_n - p_w)
- \f]
- * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
- * that the last step is assumes that the capillary
- * pressure-saturation curve can be uniquely inverted, so it is not
- * possible to set the capillary pressure to zero when using the
- * Richards model!
+ * * \f$ q_w \f$ is a source or sink term in the wetting phase.
  */
 
 #ifndef DUMUX_RICHARDSNC_MODEL_HH
diff --git a/dumux/porousmediumflow/richards/model.hh b/dumux/porousmediumflow/richards/model.hh
index bb0e4f084251841e37bf36abeff43961476abf98..00bdb7d97a456a4733540228fbf7e92a56e00e20 100644
--- a/dumux/porousmediumflow/richards/model.hh
+++ b/dumux/porousmediumflow/richards/model.hh
@@ -26,43 +26,27 @@
  q_w,
  \f]
  *
- * is frequently used to
- * approximate the water distribution above the groundwater level.
- *
- * It can be derived from the two-phase equations, i.e.
- \f[
- \phi\frac{\partial S_\alpha \varrho_\alpha}{\partial t}
- -
- \nabla \cdot \left\lbrace
- \varrho_\alpha \frac{k_{r\alpha}}{\mu_\alpha}\; \mathbf{K} \;
- \left(\nabla
- p_\alpha - \varrho_\alpha \textbf{g}
- \right)
- \right\rbrace
- =
- q_\alpha,
- \f]
- *
  * where:
  * * \f$ \phi \f$ is the porosity of the porous medium,
- * * \f$ S_\alpha \f$ represents the saturation of phase \f$ \alpha \f$,
- * * \f$ \varrho_\alpha \f$ is the mass density of phase \f$ \alpha \f$,
- * * \f$ k_{r\alpha} \f$ is the relative permeability of phase \f$ \alpha \f$,
- * * \f$ \mu_\alpha \f$ is the dynamic viscosity of phase \f$ \alpha \f$,
+ * * \f$ S_w \f$ represents the water saturation,
+ * * \f$ \varrho_w \f$ is the water density,
+ * * \f$ k_{rw} \f$ is the relative permeability of the water phase,
+ * * \f$ \mu_w \f$ is the dynamic viscosity of the water phase,
  * * \f$ \mathbf{K} \f$ is the intrinsic permeability tensor,
- * * \f$ p_\alpha \f$ is the pressure of phase \f$ \alpha \f$,
+ * * \f$ p_w \f$ is the liquid water pressure,
  * * \f$ \mathbf{g} \f$ is the gravitational acceleration vector,
- * * \f$ q_\alpha \f$ is a source or sink term.
+ * * \f$ q_w \f$ is a source or sink term.
  *
+ * It can be derived from the two-phase flow equations.
  * In contrast to the full two-phase model, the Richards model assumes
  * gas as the nonwetting fluid and that it exhibits a much lower
  * viscosity than the (liquid) wetting phase. (For example at
  * atmospheric pressure and at room temperature, the viscosity of air
  * is only about \f$1\%\f$ of the viscosity of liquid water.) As a
- * consequence, the \f$\frac{k_{r\alpha}}{\mu_\alpha}\f$ term
- * typically is much larger for the gas phase than for the wetting
+ * consequence, the mobility (\f$\frac{k_{r}}{\mu}\f$) is
+ * typically much larger for the gas phase than for the wetting
  * phase. For this reason, the Richards model assumes that
- * \f$\frac{k_{rn}}{\mu_n}\f$ is infinitely large. This implies that
+ * gas phase mobility is infinitely large. This implies that
  * the pressure of the gas phase is equivalent to the static pressure
  * distribution and that therefore, mass conservation only needs to be
  * considered for the wetting phase.
@@ -72,9 +56,9 @@
  * saturation is calculated using the inverse of the capillary
  * pressure, i.e.
  \f[
- S_w = p_c^{-1}(p_n - p_w)
+ S_w = p_c^{-1}(p_g - p_w)
  \f]
  * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
  * that the last step is assumes that the capillary
  * pressure-saturation curve can be uniquely inverted, so it is not
  * possible to set the capillary pressure to zero when using the
@@ -72,9 +56,9 @@
  \f]
- * holds, where \f$p_n\f$ is a given reference pressure. Nota bene,
+ * holds, where \f$p_g\f$ is a given reference gas pressure. Nota bene,
  * that the last step is assumes that the capillary
  * pressure-saturation curve can be uniquely inverted, so it is not